@@ -1,9 +1,12 @@
-#! /usr/bin/perl -w
+#!/usr/bin/perl
 
 # $Id$
 
 use XML::LibXML;
 
+use strict;
+use warnings;
+
 my $parser = XML::LibXML->new();
 my $xpath = shift @ARGV;
 
