@@ -17,7 +17,6 @@ no warnings 'recursion';
 use Encode ();
 
 use vars qw(@error_domains $VERSION $WARNINGS);
-use Carp;
 use overload
   '""' => \&as_string,
   'eq' => sub {
@@ -29,7 +28,7 @@ use overload
   fallback => 1;
 
 $WARNINGS = 0; # 0: suppress, 1: report via warn, 2: report via die
-$VERSION = "2.0206"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "2.0207"; # VERSION TEMPLATE: DO NOT CHANGE
 
 use constant XML_ERR_NONE            => 0;
 use constant XML_ERR_WARNING         => 1; # A simple warning
@@ -243,7 +242,7 @@ sub as_string {
       # warnings.  This has the pleasing benefit of making the test suite
       # run warning-free.
       no warnings 'utf8';
-      my $context = Encode::encode('utf8', $self->{context}, Encode::FB_DEFAULT);
+      my $context = Encode::encode('UTF-8', $self->{context});
       $msg.=$context."\n";
       $context = substr($context,0,$self->{column});
       $context=~s/[^\t]/ /g;
@@ -254,7 +253,7 @@ sub as_string {
 
 sub dump {
   my ($self)=@_;
-  use Data::Dumper;
+  require Data::Dumper;
   return Data::Dumper->new([$self],['error'])->Dump;
 }
 
